function [TalphaPlus, TindMPlus, TR]= semi_unmixing(y,Mlibrary,Nmc)

%------------------------------------------------------------------
% LINEAR SPECTRAL UNMIXING
% by N. DOBIGEON and J.-Y. TOURNERET 
% IRIT/ENSEEIHT/TSA - France - 2007
% 
% INPUT
%       y        : the pixel to be unmixed
%       Mlibrary : the spectral library
%       Nmc      : number of MCMC iterations
%
% OUTPUT
%       TalphaPlus : the samples \alpha^+ generated by the procedure
%       TindMPlus  : the indices of the endmember spectra generated
%       TR         : the number of component generated
%
%------------------------------------------------------------------


% number of spectral bands x maximum number of endmember spectra
[L Rmax] = size(Mlibrary);

% initialization of the parameters/hyperparameters
indMPlus = [5 6 3 2 4 1];
R = length(indMPlus);
sigma2 = 1;
alphaPlus = ones(R,1)/R;

% proba of the jumps used in the RJ-MCMC
proba_b = [1/2 1/2  ones(1,Rmax-3)/3  0 ];
proba_d = [ 0   0   ones(1,Rmax-3)/3 1/2];
proba_u = 1-(proba_b+proba_d);
t = 0.01;

h = waitbar(0,'Sampling...','CreateCancelBtn','closereq', 'name', 'UNMIXING...');

TindMPlus = zeros(Rmax,Nmc);
TalphaPlus = zeros(Rmax,Nmc);
TR = zeros(1,Nmc);

% beginning
for m_compt=1:Nmc;
    waitbar(m_compt/Nmc,h)
    
    % updating the endmember spectrum matrix
    [R, alphaPlus, indMPlus ]= update_MPlus(R,alphaPlus,indMPlus,y,sigma2,proba_d,proba_u,proba_b,Mlibrary,Rmax);
        
    % correction to remove the negligible abundances coefficients
    [R, alphaPlus, indMPlus] = correction(R, alphaPlus, indMPlus,t);
    TR(m_compt) = R;
    
    MPlus = Mlibrary(:,indMPlus);
    TindMPlus(1:R,m_compt) = indMPlus;
      
    % useful quantities
    u = ones(R-1,1);
    M = MPlus(:,1:(R-1));
    mr = MPlus(:,R);
    invT = inv((M-mr*u')'*(M-mr*u'));
    
    % updating the abundance coefficient
    alphaPlus = sample_alphaPlus(alphaPlus,y,invT,MPlus,sigma2);    
    TalphaPlus(indMPlus,m_compt) = alphaPlus;
    
    % updating the noise variance
    sigma2 = sample_sigma2(L,y,MPlus,R,alphaPlus);
end
close(h)

    